<?php

declare(strict_types=1);

namespace Drupal\rdf_sync\Encoder;

use EasyRdf\Format;
use EasyRdf\Graph;
use Symfony\Component\Serializer\Encoder\EncoderInterface;

/**
 * Base encoder.
 */
class RdfSyncEncoder implements EncoderInterface {

  /**
   * Memory cache for supported formats.
   *
   * @var \EasyRdf\Serialiser[]
   */
  protected static array $supportedFormats;

  /**
   * {@inheritdoc}
   */
  public function supportsEncoding($format): bool {
    return !empty(static::getSupportedFormats()[$format]);
  }

  /**
   * {@inheritdoc}
   */
  public function encode($data, $format, array $context = []): string {
    $graph = new Graph();
    $graph->parse($data, 'php');
    return $graph->serialise($format);
  }

  /**
   * Builds a list of supported formats.
   *
   * @return \EasyRdf\Serialiser[]
   *   List of supported formats.
   */
  public static function getSupportedFormats(): array {
    if (!isset(static::$supportedFormats)) {
      $registeredFormats = array_flip(\Drupal::getContainer()->getParameter('rdf_sync.format'));
      $rdfSerializers = Format::getFormats();
      static::$supportedFormats = array_intersect_key($rdfSerializers, $registeredFormats);
    }
    return static::$supportedFormats;
  }

}
